@@ -1,16 +1,16 @@
 package Perinci::Sub::XCompletion::firefox_profile_name;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
-our $DIST = 'Sah-Schemas-Firefox'; # DIST
-our $VERSION = '0.003'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
 use Complete::Firefox qw(complete_firefox_profile_name);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-04-17'; # DATE
+our $DIST = 'Sah-Schemas-Firefox'; # DIST
+our $VERSION = '0.004'; # VERSION
+
 our %SPEC;
 
 $SPEC{gen_completion} = {
@@ -39,7 +39,7 @@ Perinci::Sub::XCompletion::firefox_profile_name - Generate completion for Firefo
 
 =head1 VERSION
 
-This document describes version 0.003 of Perinci::Sub::XCompletion::firefox_profile_name (from Perl distribution Sah-Schemas-Firefox), released on 2021-07-19.
+This document describes version 0.004 of Perinci::Sub::XCompletion::firefox_profile_name (from Perl distribution Sah-Schemas-Firefox), released on 2023-04-17.
 
 =head1 SYNOPSIS
 
@@ -75,6 +75,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Firefox>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Firefox>
@@ -83,15 +112,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
